@@ -60,6 +60,7 @@ class MessageCode(Enum):
 
 BOARDS = [
     Boards.STM32F469I_DISCO.value,
+    Boards.STM32F769I_DISCO.value,
     Boards.STM32H747I_DISCO.value,
     Boards.STM32F407G_DISCO.value,
     Boards.STM32F411E_DISCO.value,
@@ -68,6 +69,7 @@ BOARDS = [
 
 AUDIO_DEBUG_RECORD_DURATION_SEC = {
     Boards.STM32F469I_DISCO.value: 3,
+    Boards.STM32F769I_DISCO.value: 3,
     Boards.STM32H747I_DISCO.value: 3,
     Boards.STM32F407G_DISCO.value: 1,
     Boards.STM32F411E_DISCO.value: 1,
